/*****************************************************************************
 * © 2017 Avaya Inc. All rights reserved.
 ****************************************************************************/
package com.avaya.services.CallDeflection;

import com.avaya.collaboration.call.Call;

interface CallDeflectionOperations
{
    void addPartyToCall(Call call);

    void sendEmail();

    void sendSms(Call call);

    void dropCall(Call call);
}
